@@ -33,11 +33,11 @@ var searchData=
   ['messageloopcallback_30',['MessageLoopCallback',['../structOSCReceiver_1_1MessageLoopCallback.html',1,'OSCReceiver']]],
   ['messagemanager_31',['MessageManager',['../classMessageManager.html',1,'']]],
   ['messagemanagerlock_32',['MessageManagerLock',['../classMessageManagerLock.html',1,'']]],
-  ['messagethread_33',['MessageThread',['../classMessageThread.html',1,'']]],
-  ['midibuffer_34',['MidiBuffer',['../classMidiBuffer.html',1,'']]],
-  ['midibufferiterator_35',['MidiBufferIterator',['../classMidiBufferIterator.html',1,'']]],
-  ['mididataconcatenator_36',['MidiDataConcatenator',['../classMidiDataConcatenator.html',1,'']]],
-  ['midideviceinfo_37',['MidiDeviceInfo',['../structMidiDeviceInfo.html',1,'']]],
+  ['midibuffer_33',['MidiBuffer',['../classMidiBuffer.html',1,'']]],
+  ['midibufferiterator_34',['MidiBufferIterator',['../classMidiBufferIterator.html',1,'']]],
+  ['mididataconcatenator_35',['MidiDataConcatenator',['../classMidiDataConcatenator.html',1,'']]],
+  ['midideviceinfo_36',['MidiDeviceInfo',['../structMidiDeviceInfo.html',1,'']]],
+  ['mididevicelistconnection_37',['MidiDeviceListConnection',['../classMidiDeviceListConnection.html',1,'']]],
   ['midieventholder_38',['MidiEventHolder',['../classMidiMessageSequence_1_1MidiEventHolder.html',1,'MidiMessageSequence']]],
   ['midifile_39',['MidiFile',['../classMidiFile.html',1,'']]],
   ['midiinput_40',['MidiInput',['../classMidiInput.html',1,'']]],
