@@ -4,13 +4,13 @@ var indexSectionsWithContent =
   1: "abcdefghijklmnopqrstuvwxz",
   2: "acdgjpstuv",
   3: "cj",
-  4: "abcdefghijklmnopqrstuvwxyz~",
+  4: "_abcdefghijklmnopqrstuvwxyz~",
   5: "abcdefghijklmnopqrstuvwxyz",
   6: "acdefghijklmnopqrstuvwz",
   7: "abcdefghijklmnoprstuvwz",
   8: "abcdefghijklmnopqrstuvwxyz",
   9: "cgjs",
-  10: "deg",
+  10: "egjx",
   11: "abcdefghijklmnopstuvwxz",
   12: "t"
 };
